import React from 'react'
import { fw } from '@entityseven/rage-fw-browser'

import { AuthEvent } from '../../../../shared/events'

import Input from '../../components/ui/Input'
import Checkbox from '../../components/ui/Checkbox'
import Button from '../../components/ui/Button'
import { useLoginForm } from '../../hooks/useLoginForm'
import { LoginFormData } from '../../validation'

const LoginPage: React.FC = () => {
    const handleLoginSuccess = async (data: LoginFormData) => {
        const tempData = {
            login: data.identifier,
            password: data.password,
        }

        const response = await fw.event.triggerServer(AuthEvent.LOGIN, [
            tempData,
        ])

        console.log(response)
    }

    const {
        formData,
        errors,
        isLoading,
        submitError,
        handleChange,
        handleSubmit,
    } = useLoginForm({ onSubmitSuccess: handleLoginSuccess })

    return (
        <div className="min-h-screen bg-gray-100 flex items-center justify-center py-12 px-4 sm:px-6 lg:px-8">
            <div className="max-w-md w-full space-y-8 bg-white p-10 rounded-lg shadow-md">
                <div>
                    <h2 className="mt-6 text-center text-3xl font-extrabold text-gray-900">
                        Sign in to your account
                    </h2>
                    {/* Optional: Link to registration page */}
                    {/* <p className="mt-2 text-center text-sm text-gray-600">
                        Or{' '}
                        <a href="/register" className="font-medium text-sky-600 hover:text-sky-500">
                            create a new account
                        </a>
                    </p> */}
                </div>
                <form
                    className="mt-8 space-y-6"
                    onSubmit={handleSubmit}
                    noValidate
                >
                    {/* Display general submission errors */}
                    {submitError && (
                        <div
                            className="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative"
                            role="alert"
                        >
                            <strong className="font-bold">Error: </strong>
                            <span className="block sm:inline">
                                {submitError}
                            </span>
                        </div>
                    )}

                    <div className="rounded-md shadow-sm -space-y-px">
                        <Input
                            label="Username"
                            id="identifier"
                            name="identifier"
                            type="text" // Use text to allow both email and username
                            autoComplete="username" // Browsers often use 'username' for this field
                            required
                            placeholder="Username"
                            value={formData.identifier}
                            onChange={handleChange}
                            error={errors.identifier}
                        />
                        <Input
                            label="Password"
                            id="password"
                            name="password"
                            type="password"
                            autoComplete="current-password"
                            required
                            placeholder="Password"
                            value={formData.password}
                            onChange={handleChange}
                            error={errors.password}
                        />
                    </div>

                    <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between">
                        <div className="flex flex-col">
                            <Checkbox
                                label="Remember username"
                                id="saveLogin"
                                name="saveLogin"
                                checked={formData.saveLogin}
                                onChange={handleChange}
                            />
                            <Checkbox
                                label="Remember password"
                                id="savePassword"
                                name="savePassword"
                                checked={formData.savePassword}
                                onChange={handleChange}
                                // Add a warning or disable based on security policy
                            />
                        </div>

                        {/* Optional: Forgot Password Link */}
                        {/* <div className="text-sm mt-2 sm:mt-0">
                            <a href="/forgot-password" className="font-medium text-sky-600 hover:text-sky-500">
                                Forgot your password?
                            </a>
                        </div> */}
                    </div>

                    <div>
                        <Button
                            type="submit"
                            isLoading={isLoading}
                            disabled={isLoading}
                        >
                            {isLoading ? 'Signing In...' : 'Sign In'}
                        </Button>
                    </div>
                </form>
            </div>
        </div>
    )
}

export default LoginPage
