import React from 'react'

import { fw } from '@entityseven/rage-fw-browser'

import { AuthEvent } from '../../../../shared/events'

import Input from '../../components/ui/Input'
import Button from '../../components/ui/Button'
import { useRegisterForm } from '../../hooks/useRegisterForm'
import { RegisterFormData } from '../../validation'

const RegisterPage: React.FC = () => {
    const handleRegistrationSuccess = async (data: RegisterFormData) => {
        const tempData = {
            login: data.username,
            password: data.password,
            email: data.email,
        }

        const response = await fw.event.triggerServer(AuthEvent.REGISTER, [
            tempData,
        ])

        console.log(response)
    }

    const {
        formData,
        errors,
        isLoading,
        submitError,
        handleChange,
        handleSubmit,
    } = useRegisterForm({ onSubmitSuccess: handleRegistrationSuccess })

    return (
        <div className="min-h-screen bg-gray-100 flex items-center justify-center py-12 px-4 sm:px-6 lg:px-8">
            <div className="max-w-md w-full space-y-8 bg-white p-10 rounded-lg shadow-md">
                <div>
                    <h2 className="mt-6 text-center text-3xl font-extrabold text-gray-900">
                        Create your account
                    </h2>
                    {/* Optional: Link to login page */}
                    {/* <p className="mt-2 text-center text-sm text-gray-600">
                        Or{' '}
                        <a href="/login" className="font-medium text-sky-600 hover:text-sky-500">
                            sign in to your existing account
                        </a>
                    </p> */}
                </div>
                <form
                    className="mt-8 space-y-6"
                    onSubmit={handleSubmit}
                    noValidate
                >
                    {/* Display general submission errors */}
                    {submitError && (
                        <div
                            className="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative"
                            role="alert"
                        >
                            <strong className="font-bold">Error: </strong>
                            <span className="block sm:inline">
                                {submitError}
                            </span>
                        </div>
                    )}

                    {/* Use hidden input for honeypot or CSRF token if needed */}
                    {/* <input type="hidden" name="remember" defaultValue="true" /> */}
                    <div className="rounded-md shadow-sm -space-y-px">
                        <Input
                            label="Username"
                            id="username"
                            name="username"
                            type="text"
                            autoComplete="username"
                            required
                            placeholder="Choose a username"
                            value={formData.username}
                            onChange={handleChange}
                            error={errors.username}
                        />
                        <Input
                            label="Email address"
                            id="email"
                            name="email"
                            type="email"
                            autoComplete="email"
                            required
                            placeholder="your@email.com"
                            value={formData.email}
                            onChange={handleChange}
                            error={errors.email}
                        />
                        <Input
                            label="Password"
                            id="password"
                            name="password"
                            type="password"
                            autoComplete="new-password"
                            required
                            placeholder="Create a password"
                            value={formData.password}
                            onChange={handleChange}
                            error={errors.password}
                        />
                        <Input
                            label="Repeat Password"
                            id="passwordRepeat"
                            name="passwordRepeat"
                            type="password"
                            autoComplete="new-password"
                            required
                            placeholder="Confirm your password"
                            value={formData.passwordRepeat}
                            onChange={handleChange}
                            error={errors.passwordRepeat}
                        />
                        <Input
                            label="Promocode (Optional)"
                            id="promocode"
                            name="promocode"
                            type="text"
                            placeholder="Enter promocode if you have one"
                            value={formData.promocode || ''}
                            onChange={handleChange}
                            error={errors.promocode}
                        />
                    </div>

                    <div>
                        <Button
                            type="submit"
                            isLoading={isLoading}
                            disabled={isLoading}
                        >
                            {isLoading ? 'Registering...' : 'Register'}
                        </Button>
                    </div>
                </form>
            </div>
        </div>
    )
}

export default RegisterPage
