import { z } from 'zod'

// --- Registration Schema ---
export const registerSchema = z
    .object({
        username: z
            .string()
            .min(3, { message: 'Username must be at least 3 characters long' })
            .max(20, { message: 'Username cannot exceed 20 characters' })
            .regex(/^[a-zA-Z0-9_]+$/, {
                message:
                    'Username can only contain letters, numbers, and underscores',
            }),
        email: z.string().email({ message: 'Invalid email address' }),
        password: z
            .string()
            .min(8, { message: 'Password must be at least 8 characters long' }),
        // Optional: Add more complexity requirements if needed
        // .regex(/^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)[a-zA-Z\d]{8,}$/, { message: "Password must contain uppercase, lowercase, and number" })
        passwordRepeat: z.string(),
        promocode: z.string().optional(), // Promocode is optional
    })
    .refine(data => data.password === data.passwordRepeat, {
        message: "Passwords don't match",
        path: ['passwordRepeat'], // Set error path to passwordRepeat field
    })

export type RegisterFormData = z.infer<typeof registerSchema>
