import { fw } from '@entityseven/rage-fw-server'
import { AuthEvent } from '@shared/events'

import md5 from 'md5'

import { eq, or } from 'drizzle-orm'

import { usersTable } from './db/schema'
import { db } from './db'

fw.event.register(AuthEvent.REGISTER, async (player, [data]) => {
    const { login, email, password } = data

    const normalizedEmail = email.toLowerCase()
    const normalizedLogin = login.toLowerCase()

    try {
        const existingUser = await db
            .select()
            .from(usersTable)
            .where(
                or(
                    eq(usersTable.login, normalizedLogin),
                    eq(usersTable.email, normalizedEmail),
                    eq(usersTable.socialClub, player.socialClub),
                ),
            )

        if (existingUser.length > 0) {
            return 'User already exists'
        }

        const user: typeof usersTable.$inferInsert = {
            socialClub: player.socialClub,
            password: md5(password), // we can use md5 for simplicity, but in production you should use more secure hashing algorithms
            email: normalizedEmail,
            login: normalizedLogin,
        }

        await db.insert(usersTable).values(user)
    } catch (e) {
        console.log(e)
        return 'Something went wrong'
    }

    console.log('User registered:', player.socialClub)

    return 'User created successfully'
})

fw.event.register(AuthEvent.LOGIN, async (player, [data]) => {
    const { login, password } = data
    const normalizedLogin = login.toLowerCase()

    console.log('Login data', data)

    try {
        const users = await db
            .select()
            .from(usersTable)
            .where(eq(usersTable.login, normalizedLogin))

        if (users.length === 0) {
            return 'Invalid credentials'
        }

        const user = users[0]

        if (user.password !== md5(password)) {
            return 'Invalid credentials'
        }

        if (user.socialClub !== player.socialClub) {
            return 'Invalid credentials'
        }

        console.log('User logged in:', user, player.socialClub)

        // Auth success
        return 'Login successful'
    } catch (e) {
        console.error('Login error:', e)
        return 'Internal server error'
    }
})
